@@ -34,13 +34,15 @@ OC.L10N.register(
     "Connecting" : "Tengist",
     "Save" : "Vista",
     "Connect" : "Tengjast",
+    "Password required" : "Lykilorðs er krafist",
     "Account settings" : "Stillingar notandaaðgangs",
-    "Change name" : "Breyta nafni",
     "Signature" : "Undirskrift",
     "A signature is added to the text of new messages and replies." : "Undirskrift verður bætt við texta nýrra skilaboða og svarpósta.",
     "Writing mode" : "Skrifhamur",
     "Preferred writing mode for new messages and replies." : "Umbeðinn skrifhamur við gerð nýrra skilaboða og svarpósta.",
     "Mail server" : "Póstþjónn",
+    "Go back" : "Fara til baka",
+    "Change name" : "Breyta nafni",
     "Email address" : "Tölvupóstfang",
     "Add alias" : "Bæta við samheiti",
     "Cancel" : "Hætta við",
@@ -66,21 +68,15 @@ OC.L10N.register(
     "Add attachment from Files" : "Bæta við viðhengi úr skrám",
     "Enable formatting" : "Virkja sniðmótun",
     "Encrypt message with Mailvelope" : "Dulrita skilaboð með Mailvelope",
-    "Uploading attachments …" : "Sendi inn viðhengi…",
-    "Sending …" : "Sendi ...",
-    "Error sending your message" : "Villa við að senda skilaboðin þín",
-    "Go back" : "Fara til baka",
-    "Retry" : "Reyna aftur",
-    "Message sent!" : "Skilaboðin hafa verið send!",
     "Send" : "Senda",
-    "Encrypt and send" : "Dulrita og senda",
-    "Send unencrypted" : "Senda ódulritað",
     "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
     "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
+    "Confirm" : "Staðfesta",
     "No message found yet" : "Engin skilaboð hafa ennþá fundist",
     "Set up an account" : "Setja upp notandaaðgang",
     "Plain text" : "Ósniðinn texti",
     "Rich text" : "Sniðinn texti",
+    "No messages" : "Engin skilaboð",
     "Draft: " : "Drög: ",
     "Unfavorite" : "Taka úr eftirlætum",
     "Favorite" : "Eftirlæti",
@@ -90,7 +86,6 @@ OC.L10N.register(
     "Unselect" : "Afvelja",
     "Select" : "Velja",
     "Edit tags" : "Breyta merkjum",
-    "Move" : "Færa",
     "More actions" : "Fleiri aðgerðir",
     "Edit as new message" : "Breyta sem nýjum skilaboðum",
     "Create event" : "Búa til atburð",
@@ -128,6 +123,7 @@ OC.L10N.register(
     "Show images" : "Sýna myndir",
     "Message frame" : "Rammi skilaboða",
     "Quoted text" : "Tilvitnaður texti",
+    "Move" : "Færa",
     "Moving" : "Færi",
     "Quota" : "Kvóti",
     "Saving" : "Vista",
@@ -149,11 +145,17 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} skilaboð","{total} skilaboð"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ólesið af {total}","{unread} ólesin af {total}"],
     "New message" : "Ný skilaboð",
+    "Refresh" : "Endurlesa",
+    "Error sending your message" : "Villa við að senda skilaboðin þín",
+    "Retry" : "Reyna aftur",
+    "Uploading attachments …" : "Sendi inn viðhengi…",
+    "Sending …" : "Sendi ...",
     "No message selected" : "Engin skilaboð valin",
     "Message" : "Skilaboð",
     "Delete" : "Eyða",
     "Copy to clipboard" : "Afrita á klippispjald",
     "Add" : "Bæta við",
+    "Close" : "Loka",
     "Tags" : "Merki",
     "Select tags" : "Veldu merki",
     "Clear" : "Hreinsa",
@@ -164,14 +166,12 @@ OC.L10N.register(
     "Custom" : "Sérsniðið",
     "Signature …" : "Undirskrift …",
     "Save signature" : "Vista undirskrift",
-    "Set" : "Setja",
-    "Unset" : "Endurstilla",
     "Add tag" : "Bæta við merki",
     "Tag already exists" : "Merki er þegar til",
+    "Not found" : "Fannst ekki",
     "Could not load your message thread" : "Gat ekki hlaðið inn skilaboðaþræðinum þínum",
     "Mark as unread" : "Merkja allt sem ólesið",
     "Mark as read" : "Merkja sem lesið",
-    "Not found" : "Fannst ekki",
     "Remove" : "Fjarlægja",
     "(organizer)" : "(skipuleggjandi)",
     "Untitled event" : "Ónefndur atburður",
@@ -186,6 +186,8 @@ OC.L10N.register(
     "Mail app" : "Tölvupóstforrit",
     "The mail app allows users to read mails on their IMAP accounts." : "Tölvupóstforritið gerir notendum kleift að lesa póst á IMAP-aðgöngum sínum.",
     "Reset" : "Endurstilla",
+    "Client ID" : "Biðlaraauðkenni",
+    "Client secret" : "Leynilykill biðlara",
     "Email: {email}" : "Tölvupóstur: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} á {host}:{port} ({ssl} encryption)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} á {host}:{port} ({ssl} encryption)",
@@ -196,6 +198,10 @@ OC.L10N.register(
     "Port" : "Gátt",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "Með stillingunum hér fyrir ofan, mun forritið útbúa aðgangsstillingar á eftirfarandi máta:",
+    "Valid until" : "Gildir til",
+    "Certificate" : "Skilríki",
+    "Back" : "Til baka",
+    "Submit" : "Senda inn",
     "Keyboard shortcut" : "Flýtilykill",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
@@ -204,11 +210,11 @@ OC.L10N.register(
     "Older message" : "Eldri skilaboð",
     "Toggle star" : "Víxla stjörnumerkingu af/á",
     "Toggle unread" : "Víxla ólesnu af/á",
-    "Refresh" : "Endurlesa",
+    "Archive" : "Setja í safnskrá",
+    "Account connected" : "Aðgangur er tengdur",
     "Connect your mail account" : "Tengdu notandaaðganginn þinn",
     "Itinerary for {type} is not supported yet" : "Það er ekki ennþá stuðningur við leið af gerðinni {type}",
     "All" : "Allt",
-    "Archive" : "Setja í safnskrá",
     "Drafts" : "Drög",
     "Favorites" : "Eftirlæti",
     "Priority inbox" : "Forgangspósthólf",
