@@ -12,14 +12,16 @@ OC.L10N.register(
     "Cancel" : "இரத்து செய்க",
     "Favorite" : "விருப்பமான",
     "Select" : "Select",
-    "Move" : "Move",
     "Create" : "உருவாக்குக",
     "Choose" : "தெரிவுசெய்க ",
     "Other" : "மற்றவை",
+    "Move" : "Move",
     "Quota" : "பங்கு",
     "Saving" : "Saving",
+    "Refresh" : "மீள் ஏற்றுக",
     "Delete" : "நீக்குக",
     "Add" : "சேர்க்க",
+    "Close" : "மூடுக",
     "Tags" : "சீட்டுகள்",
     "Search" : "Search",
     "Date" : "Date",
@@ -28,8 +30,8 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "ஓம்புனர்",
     "Port" : "துறை ",
+    "Back" : "பின்னுக்கு",
     "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
-    "Refresh" : "மீள் ஏற்றுக",
     "All" : "எல்லாம்",
     "Favorites" : "விருப்பங்கள்"
 },
