@@ -14,65 +14,78 @@ OC.L10N.register(
     "Connecting" : "กำลังเชื่อมต่อ",
     "Save" : "บันทึก",
     "Connect" : "เชื่อมต่อ",
+    "Signature" : "ลายเซ็น",
+    "Go back" : "กลับไป",
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
-    "Sending …" : "กำลังส่ง ...",
-    "Go back" : "กลับไป",
-    "Message sent!" : "ส่งข้อความ!",
     "Send" : "ส่ง",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
-    "Read" : "อ่านแล้ว",
+    "Read" : "อ่าน",
     "Unselect" : "ยกเลิกการเลือก",
-    "Select" : "Select",
+    "Select" : "เลือก",
     "Edit tags" : "แก้ไขแท็ก",
-    "Move" : "ย้าย",
+    "Forward" : "ส่งต่อ",
     "Create" : "สร้าง",
-    "Comment" : "แสดงความคิดเห็น",
+    "Comment" : "ความคิดเห็น",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Choose" : "เลือก",
-    "Other" : "อื่นๆ",
+    "Other" : "อื่น ๆ",
     "Reply" : "ตอบกลับ",
     "Unnamed" : "ไม่มีชื่อ",
-    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บสิ่งที่แนบมาใน",
+    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
+    "Move" : "ย้าย",
     "Moving" : "กำลังย้าย",
     "Quota" : "โควต้า",
     "Saving" : "กำลังบันทึก",
     "Remove account" : "ลบบัญชี",
-    "Mark all as read" : "เลือกอ่านทั้งหมด",
+    "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Clear cache" : "ล้างแคช",
+    "Refresh" : "รีเฟรช",
+    "Sending …" : "กำลังส่ง ...",
     "Delete" : "ลบ",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
-    "Disabled" : "ปิดการใช้งาน",
-    "Enabled" : "เปิดการใช้งาน",
+    "Close" : "ปิด",
+    "Tags" : "แท็ก",
+    "Clear" : "ล้าง",
+    "Search" : "ค้นหา",
+    "Date" : "วันที่",
+    "Disabled" : "ปิดใช้งาน",
+    "Enabled" : "เปิดใช้งาน",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Remove" : "ลบออก",
     "Reset" : "ตั้งค่าใหม่",
+    "Client ID" : "รหัสไคลเอ็นต์",
+    "Client secret" : "ข้อมูลลับไคลเอ็นต์",
     "General" : "ทั่วไป",
-    "User" : "User",
+    "User" : "ผู้ใช้",
     "Host" : "โฮสต์",
     "Port" : "พอร์ต",
+    "Valid until" : "ใช้ได้จนถึง",
+    "Certificate" : "ใบรับรอง",
+    "Back" : "ย้อนกลับ",
+    "Submit" : "ส่ง",
     "Keyboard shortcut" : "แป้นพิมพ์ลัด",
-    "Keyboard shortcuts" : "ปุ่มลัด",
-    "Search" : "Search",
-    "Refresh" : "รีเฟรช",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Archive" : "ที่เก็บถาวร",
+    "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
-    "Archive" : "เอกสารเก่า",
-    "Drafts" : "แบบร่าง",
+    "Drafts" : "ฉบับร่าง",
     "Favorites" : "รายการโปรด",
-    "All inboxes" : "กล่องจดหมายทั้งหมด",
+    "All inboxes" : "กล่องขาเข้าทั้งหมด",
     "Inbox" : "กล่องขาเข้า",
     "Junk" : "อีเมลขยะ",
-    "Sent" : "ส่ง",
+    "Sent" : "ส่งแล้ว",
     "Trash" : "ถังขยะ",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "Error loading message" : "กิดข้อผิดพลาดในการโหลด",
+    "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
-    "The link leads to %s" : "ลิงค์ที่จะนำไปยัง %s",
+    "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
     "Continue to %s" : "ดำเนินการต่อไปที่ %s"
 },
 "nplurals=1; plural=0;");
