@@ -7,17 +7,22 @@ OC.L10N.register(
     "Important" : "重要",
     "Work" : "工作",
     "Personal" : "个人",
-    "To Do" : "要做的事",
+    "To Do" : "待办",
     "Later" : "稍晚",
     "Mails" : "邮件",
     "Mail" : "邮件",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 一个Nextcloud的邮箱应用软件\n\n- **🚀 于其他Nextcloud应用程序集成**目前有联系人、日历和文件 – 更多内容即将推出。\n- **📥 多邮箱账号！**个人或公司账号？没问题，这是个很好用的统一收件箱。可以连接到任何IMAP账号。\n- **🔒 发送或接收加密的邮件！** 使用出色的[Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们不是在重复造轮子！** 基于伟大的[Horde](https://horde.org) 库。\n- **📬 想要托管自己的邮件服务器？** 我们不必重新实现它，因为你可以设置[Mail-in-a-Box](https://mailinabox.email)！",
+    "Your session has expired. The page will be reloaded." : "您的会话已过期，当前页面将被重新加载。",
     "Drafts are saved in:" : "草稿邮件被保存于：",
     "Sent messages are saved in:" : "已发送邮件被保存于：",
     "Deleted messages are moved in:" : "已删除邮件被移动到：",
+    "Archived messages are moved in:" : "存档信息被移动到：",
     "Auto" : "自动",
     "Name" : "姓名",
     "Mail address" : "邮箱",
+    "name@example.org" : "name@example.org",
+    "Please enter an email of the format name@example.com" : "请输入格式为 name@example.com 的电子邮件",
     "Password" : "密码",
     "Manual" : "手动",
     "IMAP Settings" : "IMAP 设置",
@@ -35,16 +40,39 @@ OC.L10N.register(
     "SMTP Port" : "SMTP 端口",
     "SMTP User" : "SMTP 用户",
     "SMTP Password" : "SMTP 密码",
+    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "要在此应用程序中使用 Google 帐户, 您需要为 Google 启用双重身份验证并生成应用程序密码。",
     "Connecting" : "正在连接",
+    "Reconnect Google account" : "重新连接谷歌账号",
+    "Sign in with Google" : "使用谷歌登录",
     "Save" : "保存",
     "Connect" : "连接",
+    "Looking up configuration" : "查找配置",
+    "Checking mail host connectivity" : "检查邮件主机连接",
+    "Configuration discovery failed. Please use the manual settings" : "自动配置失败。 请使用手动设置",
+    "Password required" : "需要密码",
+    "Testing authentication" : "测试认证",
+    "Awaiting user consent" : "等待用户同意",
+    "Account created. Please follow the popup instructions to link your Google account" : "帐户已创建。请根据弹出的说明来关联您的 Google 帐户",
+    "Loading account" : "加载账户",
+    "Account updated. Please follow the popup instructions to reconnect your Google account" : "账户已更新。请根据弹出的说明来重新连接您的谷歌账号",
+    "Account updated" : "账户已更新",
+    "IMAP server is not reachable" : "无法访问IMAP服务器",
+    "SMTP server is not reachable" : "无法访问SMTP服务器",
+    "IMAP username or password is wrong" : "IMAP用户名或密码错误",
+    "SMTP username or password is wrong" : "SMTP用户名或密码错误",
+    "IMAP connection failed" : "IMAP连接失败",
+    "SMTP connection failed" : "SMTP连接失败",
+    "There was an error while setting up your account" : "设置您的账户时出错",
     "Account settings" : "账号设置",
-    "Change name" : "更改名称",
     "Signature" : "签名",
     "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
     "Writing mode" : "编写模式",
     "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
     "Default folders" : "默认文件夹",
+    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "用于草稿、已发送消息、已删除消息和存档消息的文件夹。",
+    "Autoresponder" : "自动回复",
+    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "自动回复来件信息。如果有人向您发送多条消息，此自动回复最多每 4 天发送一次。",
+    "Please connect to a sieve server first." : "请先连接到sieve服务器。",
     "Sieve filter rules" : "Sieve 过滤器规则",
     "Trusted senders" : "信任的发件人",
     "Mail server" : "邮件服务器",
@@ -52,6 +80,8 @@ OC.L10N.register(
     "Update alias" : "更新别名",
     "Show update alias form" : "显示更新别名表单",
     "Delete alias" : "删除别名",
+    "Go back" : "后退",
+    "Change name" : "更改名称",
     "Email address" : "电子邮件地址",
     "Add alias" : "添加别名",
     "Create alias" : "创建别名",
@@ -60,6 +90,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
     "Register as application for mail links" : "注册为邮件链接应用",
     "Show keyboard shortcuts" : "显示键盘快捷方式",
+    "Looking for a way to encrypt your emails?" : "正在寻找加密邮件的方法？",
+    "Install Mailvelope browser extension here" : "在此处安装 Mailvelope 浏览器扩展",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
     "Put my text to the bottom of a reply instead of on top of it." : "把我的信息放在回复的最下面，而不是最上面。 ",
     "Automatically classify importance of new email" : "自动分类新邮件的重要性 ",
@@ -68,6 +100,7 @@ OC.L10N.register(
     "Select account" : "选择账号",
     "To" : "收件人",
     "Contact or email address …" : "联系人或邮箱地址...",
+    "Toggle recipients list mode" : "切换收件人列表模式",
     "Cc" : "抄送",
     "Bcc" : "密送",
     "No contacts found." : "未找到联系人。",
@@ -77,55 +110,67 @@ OC.L10N.register(
     "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
     "Write message …" : "编写消息...",
     "Saving draft …" : "正在保存草稿 …",
+    "Error saving draft" : "保存草稿时出错",
     "Draft saved" : "草稿已保存",
+    "Save draft" : "保存草稿",
     "Discard & close draft" : "丢弃并关闭草稿",
     "Upload attachment" : "上传附件",
     "Add attachment from Files" : "从文件添加附件",
+    "Send later" : "稍后发送",
     "Enable formatting" : "启用格式化",
+    "Disable formatting" : "禁用格式化",
     "Request a read receipt" : "请求已读回执",
     "Encrypt message with Mailvelope" : "使用 Mailvelope 加密邮件",
+    "Send now" : "立即发送",
+    "Tomorrow morning" : "明天早上",
+    "Tomorrow afternoon" : "明天下午",
+    "Monday morning" : "星期一早上",
+    "Custom date and time" : "自定义日期和时间",
     "Enter a date" : "输入日期",
-    "Uploading attachments …" : "正在上传附件…",
-    "Sending …" : "正在发送…",
-    "Error sending your message" : "发送您的消息时出错",
-    "Go back" : "后退",
-    "Retry" : "重试",
-    "Warning sending your message" : "对发送信息提出警告",
-    "Send anyway" : "不论如何都要发送",
-    "Message sent!" : "消息已发送！",
     "Add share link from {productName} Files" : "添加来自 {productName} 文件的共享链接",
     "Send" : "发送",
-    "Encrypt and send" : "加密并发送",
-    "Send unencrypted" : "不加密发送",
     "Message {id} could not be found" : "消息 {id} 未找到",
-    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "你在To 和/或 Cc 中正尝试发送给许多收件人。考虑使用 Bcc 来隐藏收件人地址。",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何现有格式（例如粗体、斜体、下划线或内联图像）都将被删除。",
+    "Turn off formatting" : "关闭格式化",
+    "Turn off and remove formatting" : "关闭并删除格式",
+    "Keep formatting" : "保持格式化",
     "Choose a file to add as attachment" : "选择文件添加为附件",
     "Choose a file to share as a link" : "选择要共享的文件作为链接",
+    "_{count} attachment_::_{count} attachments_" : ["{count} 附件"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超出了允许的附件最大大小 {size}。请通过链接共享文件。"],
+    "Confirm" : "确认",
     "No message found yet" : "暂无消息",
     "Set up an account" : "设置一个账号",
     "Plain text" : "纯文本",
     "Rich text" : "富文本",
     "No messages in this mailbox" : "此邮箱中没有消息",
+    "No messages" : "没有消息",
     "Draft: " : "草稿: ",
+    "Encrypted message" : "已加密邮件",
+    "This message is unread" : "此邮件未读",
     "Unfavorite" : "取消收藏",
     "Favorite" : "收藏",
+    "Unread" : "未读",
     "Read" : "读取",
+    "Unimportant" : "不重要",
     "Mark not spam" : "标记为非垃圾邮件",
     "Mark as spam" : "标记为垃圾邮件",
     "Unselect" : "取消选择",
     "Select" : "选择",
     "Edit tags" : "编辑标签",
-    "Move" : "移动",
     "Move thread" : "移动线程",
+    "Archive thread" : "归档线程",
     "Delete thread" : "删除线程",
     "More actions" : "更多操作 ",
     "Edit as new message" : "编辑为新消息",
     "Create event" : "创建事件",
+    "Create task" : "创建任务",
+    "Download message" : "下载邮件",
     "Blind copy recipients only" : "仅向收件人发送无信头副本",
+    "No subject" : "无主题",
     "No trash mailbox configured" : "没有配置垃圾邮箱",
     "Could not delete message" : "无法删除消息",
+    "Could not archive message" : "无法归档邮件",
     "Forward" : "转发",
     "Load more" : "加载更多",
     "_Mark {number} unread_::_Mark {number} unread_" : ["标记 {number} 封未读"],
@@ -143,10 +188,25 @@ OC.L10N.register(
     "Create" : "创建",
     "Event created" : "已创建事件",
     "Could not create event" : "无法建立事件",
+    "You accepted this invitation" : "你接受了邀请",
+    "You tentatively accepted this invitation" : "您暂时接受了此邀请",
+    "You declined this invitation" : "您拒绝了此邀请",
+    "You already reacted to this invitation" : "您已对此邀请作出回应",
+    "You have been invited to an event" : "您已受邀参加活动",
+    "This event was cancelled" : "此活动已取消",
+    "Save to" : "保存到",
     "Comment" : "评论",
     "Accept" : "接受",
     "Decline" : "拒绝",
+    "Tentatively accept" : "暂时接受",
     "More options" : "更多选项",
+    "This event is in the past." : "这个事件已经过去了。",
+    "This event was updated" : "此活动已更新",
+    "{attendeeName} accepted your invitation" : "{attendeeName} 接受了您的邀请",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暂时接受了您的邀请",
+    "{attendeeName} declined your invitation" : "{attendeeName} 拒绝了您的邀请",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} 回应了您的邀请",
+    "Failed to save your participation status" : "无法保存您的参与状态",
     "Could not open mailbox" : "无法打开邮箱",
     "Loading messages …" : "正在加载邮件…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
@@ -160,9 +220,11 @@ OC.L10N.register(
     "Notify the sender" : "通知发件人",
     "You sent a read confirmation to the sender of this message." : "您向此消息的发送方发送了一个已读确认。",
     "Could not send mdn" : "无法发送 mdn",
+    "Reply all" : "回复全部",
     "Reply" : "回复",
     "Reply to sender only" : "只回复发送者",
     "Move message" : "移动消息",
+    "Forward message as attachment" : "将邮件作为附件转发",
     "View source" : "查看来源",
     "Download thread data for debugging" : "下载线程数据以进行调试",
     "Message source" : "消息来源",
@@ -173,9 +235,11 @@ OC.L10N.register(
     "Unnamed" : "未命名",
     "Embedded message" : "嵌入式消息",
     "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
+    "View fewer attachments" : "查看更少的附件",
     "Save all to Files" : "全部保存到文件",
     "Download Zip" : "下载 Zip",
     "Choose a folder to store the attachments in" : "选择附件保存的目录",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["查看 {count} 个附件"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
     "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
     "Show images" : "显示图片",
@@ -184,9 +248,13 @@ OC.L10N.register(
     "Always show images from {domain}" : "始终显示来自 {domain} 的图片",
     "Message frame" : "消息框",
     "Quoted text" : "引用文字",
+    "Move" : "移动",
     "Moving" : "移动",
     "Moving thread" : "正在移动线程",
     "Moving message" : "正在移动消息",
+    "Mail settings" : "邮件设置",
+    "Provisioned account is disabled" : "预配帐户已禁用",
+    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "请使用密码登录以启用此帐户。当前会话正在使用无密码身份验证，例如 SSO 或 WebAuthn。",
     "Quota" : "配额",
     "Show only subscribed mailboxes" : "只显示已订阅的邮箱",
     "Add mailbox" : "添加邮箱",
@@ -211,25 +279,62 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
     "Subscribed" : "已订阅",
     "Sync in background" : "后台同步",
+    "Clear mailbox" : "清空邮箱",
     "Delete mailbox" : "删除邮箱",
+    "All messages in mailbox will be deleted." : "邮箱中的所有消息将被删除。",
+    "Clear mailbox {name}" : "清除 {name} 邮箱",
     "The mailbox and all messages in it will be deleted." : "邮箱和其中的所有邮件都将被删除。",
     "Delete mailbox {name}" : "删除邮箱 {name}",
     "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
     "_{total} message_::_{total} messages_" : ["{total} 条消息"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
+    "Outbox" : "发件箱",
     "New message" : "新建消息",
+    "Refresh" : "刷新",
+    "Error sending your message" : "发送您的消息时出错",
+    "Retry" : "重试",
+    "Uploading attachments …" : "正在上传附件…",
+    "Sending …" : "正在发送…",
+    "Warning sending your message" : "对发送信息提出警告",
+    "Send anyway" : "不论如何都要发送",
+    "Edit message" : "编辑邮件",
+    "Draft" : "草稿",
+    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "你在To 和/或 Cc 中正尝试发送给许多收件人。考虑使用 Bcc 来隐藏收件人地址。",
+    "Message discarded" : "邮件已丢弃",
+    "Could not discard message" : "无法丢弃邮件",
     "No message selected" : "没有选择消息",
+    "Autoresponder off" : "自动回复关闭",
+    "Autoresponder on" : "自动回复开启",
+    "First day" : "第一天",
+    "Last day (optional)" : "最后一天（可选）",
+    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} 将替换为您要回复的邮件的主题",
     "Message" : "消息",
     "Oh Snap!" : "噢！",
+    "Save autoresponder" : "保存自动回复",
+    "Could not open outbox" : "无法打开发件箱",
+    "Pending or not sent messages will show up here" : "待处理或未发送的邮件将会显示在这里",
     "Delete" : "删除",
+    "Message could not be sent" : "无法发送邮件",
+    "Message deleted" : "邮件已删除",
     "Contacts with this address" : "使用此地址的联系人 ",
     "Add to Contact" : "添加到联系人",
     "New Contact" : "新联系人",
     "Copy to clipboard" : "复制到剪贴板",
     "Contact name …" : "联系人姓名 …",
     "Add" : "新增",
+    "Copied email address to clipboard" : "已复制电子邮件地址到剪贴板",
+    "Could not copy email address to clipboard" : "无法复制电子邮件地址到剪贴板",
+    "Search in mailbox" : "在邮箱中搜索",
+    "Close" : "关闭",
+    "Search parameters" : "搜索参数",
+    "Search term" : "关键字",
+    "Pick a start date" : "选择开始时间",
+    "Pick an end date" : "选择结束时间",
     "Tags" : "标签",
     "Select tags" : "选择标签",
+    "Marked as" : "标记为",
+    "Has attachments" : "有附件",
     "Clear" : "清空",
     "Search" : "搜索",
     "Date" : "日期",
@@ -246,23 +351,31 @@ OC.L10N.register(
     "Save sieve settings" : "保存 sieve 设置",
     "Save sieve script" : "保存 sieve 脚本",
     "Signature …" : "签名...",
+    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "您的签名大于 2 MB。这可能会影响编辑器的性能。",
     "Save signature" : "保存签名",
     "Place signature above quoted text" : "把签名放在引用文本上方",
     "Add default tags" : "添加默认标签",
     "Rename tag" : "重命名标签",
     "Saving new tag name …" : "保存新标签名中 …",
-    "Set" : "设置",
-    "Unset" : "取消设置",
     "Add tag" : "添加标签",
     "Saving tag …" : "正在保存标签 …",
+    "Tag name is a hidden system tag" : "标记名称是一个隐藏的系统标记",
     "Tag already exists" : "标签已存在",
     "An error occurred, unable to create the tag." : "发生了一个错误，无法创建标签",
     "An error occurred, unable to rename the tag." : "发生错误，无法重命名标签",
+    "Loading thread" : "加载主题",
+    "Not found" : "没有找到",
     "Could not load your message thread" : "无法加载您的消息线线程",
+    "The thread doesn't exist or has been deleted" : "该主题不存在或已被删除",
+    "Unsubscribe" : "取消订阅",
+    "Mark as unfavorite" : "取消标记为我的最爱",
+    "Mark as favorite" : "标记为我的最爱",
     "Mark as unread" : "标为未读",
     "Mark as read" : "标为已读",
+    "Archive message" : "存档消息",
     "Delete message" : "删除消息",
-    "Not found" : "没有找到",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "此邮件包含经过验证的数字 S/MIME 签名。 邮件自发送后未更改。",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "此邮件包含未经验证的数字 S/MIME 签名。邮件可能在发送后被更改，或者签名者的证书不受信任。",
     "Remove" : "删除",
     "No senders are trusted at the moment." : "当前没有发件人是受信任的",
     "Could not remove trusted sender {sender}" : "无法删除受信任的发件人 {sender} ",
@@ -293,9 +406,14 @@ OC.L10N.register(
     "Provisioning Configurations" : "账户开通配置",
     "Add new config" : "添加新配置",
     "Provision all accounts" : "开通所有账户",
+    "Allow additional mail accounts" : "允许其他邮件帐户",
+    "Allow additional Mail accounts from User Settings" : "允许在用户设置的其他邮件帐户",
     "Anti Spam Service" : "反垃圾邮件服务",
     "You can set up an anti spam service email address here." : "你可以在此设置反垃圾邮件服务的电邮地址。",
     "Any email that is marked as spam will be sent to the anti spam service." : "任何被标记为垃圾邮件的电子邮件将被发送到反垃圾邮件服务",
+    "Gmail integration" : "Gmail 集成",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 允许用户通过 IMAP 访问他们的电子邮件。出于安全原因，只有使用 OAuth 2.0 连接或使用双重身份验证和应用程序密码的 Google 帐户才能进行此访问。",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必须在 Google Cloud 控制台中为“Web 应用程序”注册一个新的客户端 ID。 添加 URL {url} 作为授权重定向 URI。",
     "Successfully updated config for \"{domain}\"" : "成功更新了  \"{domain}\" 的配置",
     "Error saving config" : "保存配置时出错",
     "Saved config for \"{domain}\"" : "已保存 \"{domain}\" 的配置",
@@ -315,6 +433,13 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "保存反垃圾邮件地址出错",
     "Successfully deleted anti spam reporting email" : "成功删除反垃圾邮件报告电子邮件",
     "Error deleting anti spam reporting email" : "删除反垃圾邮件报告邮件出错",
+    "Client ID" : "客户端 ID",
+    "Client secret" : "客户端 secret",
+    "Unlink" : "取消关联",
+    "Google integration configured" : "已配置 Google 集成",
+    "Could not configure Google integration" : "无法配置 Google 集成",
+    "Google integration unlinked" : "已取消关联 Google 集成",
+    "Could not unlink Google integration" : "无法取消关联 Google 集成",
     "Domain Match: {provisioningDomain}" : "域名匹配：{provisioningDomain}",
     "Email: {email}" : "电子邮件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
@@ -340,6 +465,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "取消开通 & 删除配置",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 和 %EMAIL% 将被用户的 UID 及邮箱地址所代替",
     "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
+    "E-mail address" : "电子邮件地址",
+    "Valid until" : "有效期至",
+    "Certificate" : "证书",
+    "Back" : "返回",
+    "Submit" : "提交",
     "Keyboard shortcut" : "键盘快捷键",
     "Keyboard shortcuts" : "键盘快捷方式",
     "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
@@ -348,11 +478,13 @@ OC.L10N.register(
     "Older message" : "更早的信息",
     "Toggle star" : "切换星标",
     "Toggle unread" : "切换未读",
-    "Refresh" : "刷新",
+    "Archive" : "归档",
+    "Account connected" : "账号已连接",
+    "You can close this window" : "您可以关闭此窗口",
     "Connect your mail account" : "连接您的邮件账号",
+    "To add a mail account, please contact your administrator." : "要添加邮件帐户，请联系您的管理员。",
     "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
     "All" : "全部",
-    "Archive" : "归档",
     "Drafts" : "草稿",
     "Favorites" : "收藏",
     "Priority inbox" : "优先收件箱",
@@ -367,6 +499,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud 邮件",
     "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
     "Message sent" : "消息已发送",
+    "Could not send message" : "无法发送邮件",
     "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
     "Could not load your message" : "无法加载您的消息",
@@ -377,6 +510,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
     "Redirect" : "重定向",
     "The link leads to %s" : "链接指向 %s",
+    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此页面，你可以返回<a href=\"%s\">邮件</a>。",
     "Continue to %s" : "继续 %s"
 },
 "nplurals=1; plural=0;");
