@@ -27,18 +27,25 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Controller;
 
+use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IUserPreferences;
-use OCA\Mail\Service\OutboxService;
+use OCA\Mail\Db\SmimeCertificate;
 use OCA\Mail\Db\TagMapper;
 use OCA\Mail\Service\AccountService;
 use OCA\Mail\Service\AliasesService;
+use OCA\Mail\Service\OutboxService;
+use OCA\Mail\Service\SmimeService;
 use OCA\Viewer\Event\LoadViewer;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\RedirectResponse;
 use OCP\AppFramework\Http\TemplateResponse;
 use OCP\AppFramework\Services\IInitialState;
+use OCP\Authentication\Exceptions\CredentialsUnavailableException;
+use OCP\Authentication\Exceptions\PasswordUnavailableException;
+use OCP\Authentication\LoginCredentials\IStore as ICredentialStore;
+use OCP\Collaboration\Reference\RenderReferenceEvent;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IRequest;
@@ -47,45 +54,25 @@ use OCP\IUserSession;
 use Psr\Log\LoggerInterface;
 use Throwable;
 use function class_exists;
+use function http_build_query;
 use function json_decode;
 
 class PageController extends Controller {
-	/** @var IURLGenerator */
-	private $urlGenerator;
-
-	/** @var IConfig */
-	private $config;
-
-	/** @var AccountService */
-	private $accountService;
-
-	/** @var AliasesService */
-	private $aliasesService;
-
-	/** @var string */
-	private $currentUserId;
-
-	/** @var IUserSession */
-	private $userSession;
-
-	/** @var IUserPreferences */
-	private $preferences;
-
-	/** @var IMailManager */
-	private $mailManager;
-
-	/** @var TagMapper */
-	private $tagMapper;
-
-	/** @var IInitialState */
-	private $initialStateService;
-
-	/** @var LoggerInterface */
-	private $logger;
-
-	/** @var OutboxService */
-	private $outboxService;
+	private IURLGenerator $urlGenerator;
+	private IConfig $config;
+	private AccountService $accountService;
+	private AliasesService $aliasesService;
+	private ?string $currentUserId;
+	private IUserSession $userSession;
+	private IUserPreferences $preferences;
+	private IMailManager $mailManager;
+	private TagMapper $tagMapper;
+	private IInitialState $initialStateService;
+	private LoggerInterface $logger;
+	private OutboxService $outboxService;
 	private IEventDispatcher $dispatcher;
+	private ICredentialstore $credentialStore;
+	private SmimeService $smimeService;
 
 	public function __construct(string $appName,
 								IRequest $request,
@@ -93,15 +80,17 @@ class PageController extends Controller {
 								IConfig $config,
 								AccountService $accountService,
 								AliasesService $aliasesService,
-								?string $UserId,
-								IUserSession $userSession,
+								?string          $UserId,
+								IUserSession     $userSession,
 								IUserPreferences $preferences,
-								IMailManager $mailManager,
-								TagMapper $tagMapper,
-								IInitialState $initialStateService,
-								LoggerInterface $logger,
-								OutboxService $outboxService,
-								IEventDispatcher $dispatcher) {
+								IMailManager     $mailManager,
+								TagMapper        $tagMapper,
+								IInitialState    $initialStateService,
+								LoggerInterface  $logger,
+								OutboxService    $outboxService,
+								IEventDispatcher $dispatcher,
+								ICredentialStore $credentialStore,
+								SmimeService     $smimeService) {
 		parent::__construct($appName, $request);
 
 		$this->urlGenerator = $urlGenerator;
@@ -117,6 +106,8 @@ class PageController extends Controller {
 		$this->logger = $logger;
 		$this->outboxService = $outboxService;
 		$this->dispatcher = $dispatcher;
+		$this->credentialStore = $credentialStore;
+		$this->smimeService = $smimeService;
 	}
 
 	/**
@@ -135,6 +126,11 @@ class PageController extends Controller {
 			$this->config->getSystemValue('debug', false)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'ncVersion',
+			$this->config->getSystemValue('version', '0.0.0')
+		);
+
 		$mailAccounts = $this->accountService->findByUserId($this->currentUserId);
 		$accountsJson = [];
 		foreach ($mailAccounts as $mailAccount) {
@@ -166,6 +162,17 @@ class PageController extends Controller {
 			$this->tagMapper->getAllTagsForUser($this->currentUserId)
 		);
 
+		try {
+			$password = $this->credentialStore->getLoginCredentials()->getPassword();
+			$passwordIsUnavailable = $password === null || $password === '';
+		} catch (CredentialsUnavailableException | PasswordUnavailableException $e) {
+			$passwordIsUnavailable = true;
+		}
+		$this->initialStateService->provideInitialState(
+			'password-is-unavailable',
+			$passwordIsUnavailable,
+		);
+
 		$user = $this->userSession->getUser();
 		$response = new TemplateResponse($this->appName, 'index',
 			[
@@ -190,6 +197,40 @@ class PageController extends Controller {
 			'outbox-messages',
 			$this->outboxService->getMessages($user->getUID())
 		);
+		$googleOauthclientId = $this->config->getAppValue(Application::APP_ID, 'google_oauth_client_id');
+		if (!empty($googleOauthclientId)) {
+			$this->initialStateService->provideInitialState(
+				'google-oauth-url',
+				'https://accounts.google.com/o/oauth2/v2/auth?' . http_build_query([
+					'client_id' => $googleOauthclientId,
+					'redirect_uri' => $this->urlGenerator->linkToRouteAbsolute('mail.googleIntegration.oauthRedirect'),
+					'response_type' => 'code',
+					'prompt' => 'consent',
+					'state' => '_accountId_', // Replaced by frontend
+					'scope' => 'https://mail.google.com/',
+					'access_type' => 'offline',
+					'login_hint' => '_email_', // Replaced by frontend
+				]),
+			);
+		}
+		$microsoftOauthClientId = $this->config->getAppValue(Application::APP_ID, 'microsoft_oauth_client_id');
+		$microsoftOauthTenantId = $this->config->getAppValue(Application::APP_ID, 'microsoft_oauth_tenant_id', 'common');
+		if (!empty($microsoftOauthClientId) && !empty($microsoftOauthTenantId)) {
+			$this->initialStateService->provideInitialState(
+				'microsoft-oauth-url',
+				"https://login.microsoftonline.com/$microsoftOauthTenantId/oauth2/v2.0/authorize?" . http_build_query([
+					'client_id' => $microsoftOauthClientId,
+					'redirect_uri' => $this->urlGenerator->linkToRouteAbsolute('mail.microsoftIntegration.oauthRedirect'),
+					'response_type' => 'code',
+					'response_mode' => 'query',
+					'prompt' => 'consent',
+					'state' => '_accountId_', // Replaced by frontend
+					'scope' => 'offline_access https://outlook.office.com/IMAP.AccessAsUser.All https://outlook.office.com/SMTP.Send',
+					'access_type' => 'offline',
+					'login_hint' => '_email_', // Replaced by frontend
+				]),
+			);
+		}
 
 		// Disable scheduled send in frontend if ajax cron is used because it is unreliable
 		$cronMode = $this->config->getAppValue('core', 'backgroundjobs_mode', 'ajax');
@@ -198,10 +239,25 @@ class PageController extends Controller {
 			$cronMode === 'ajax',
 		);
 
+		$this->initialStateService->provideInitialState(
+			'allow-new-accounts',
+			$this->config->getAppValue('mail', 'allow_new_mail_accounts', 'yes') === 'yes'
+		);
+
+		$this->initialStateService->provideInitialState(
+			'smime-certificates',
+			array_map(
+				function (SmimeCertificate $certificate) {
+					return $this->smimeService->enrichCertificate($certificate);
+				},
+				$this->smimeService->findAllCertificates($user->getUID()),
+			),
+		);
+
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedFrameDomain('\'self\'');
 		$response->setContentSecurityPolicy($csp);
-
+		$this->dispatcher->dispatchTyped(new RenderReferenceEvent());
 		return $response;
 	}
 
@@ -305,7 +361,7 @@ class PageController extends Controller {
 		}
 
 		array_walk($params,
-			function (&$value, $key) {
+			static function (&$value, $key) {
 				$value = "$key=" . urlencode($value);
 			});
 		$name = '?' . implode('&', $params);
